Bases are specified as one base per csv line with the following fields:

- `base_id`: the unique id for this base
- `lon`: the longitude for the base location
- `lat`: the latitude for the base location
- `stall_count`: how many vehicles can this base accomodate
- `station_id`: (optional) the id of a station co-located with the base
